Struct S3PathBuf

pub struct S3PathBuf { /* private fields */ }
An owned S3 storage path.

Implementations

Source

impl S3PathBuf

pub fn new() -> Self

pub fn try_from<C: Into<Cow<'static, str>>, I: IntoIterator<Item = C>>( components: I, ) -> Result<Self, InvalidS3PathComponent>

pub fn try_from_str( string: impl AsRef<str>, ) -> Result<Self, InvalidS3PathComponent>

pub fn join( &mut self, component: impl Into<Cow<'static, str>>, ) -> Result<&mut Self, InvalidS3PathComponent>

pub fn as_path(&self) -> &S3Path<'_>

pub fn pop(&mut self) -> Option<Cow<'static, str>>

Pop the last component from this path, returning true if a component was removed

Methods from Deref<Target = S3Path<'static>>

pub fn to_owned(&'i self) -> S3PathBuf

Converts to an owned S3PathBuf.

pub fn join<C: Into<Cow<'static, str>>>( &self, component: C, ) -> Result<S3PathBuf, InvalidS3PathComponent>

Converts to an owned S3PathBuf and tries to append component.

pub fn is_empty(&'i self) -> bool

Returns true if this path has no components.

pub fn len(&'i self) -> usize

Returns the number of components in this path.

pub fn components(&'i self) -> impl Iterator<Item = &'i str>

Returns an iterator over the components of this path.

pub fn get(&'i self, index: usize) -> Option<&'i str>

Returns the component at the given index, or None if the index is out of bounds.

pub fn last(&'i self) -> Option<&'i str>

Returns the last component of this path, or None if the path is empty.

pub fn parent(&'i self) -> Option<&'i S3Path<'i>>

Returns all but the last component of this path, or None if the path is empty.

pub fn to_std_path_buf(&self) -> PathBuf

Convert this S3 path to a std::path::PathBuf, allowing you to use this S3 path as a system file path.

Our strong guarantee that path components only consist of ascii alphanumeric characters, ‘-’, ‘_’ and ‘.’ and that no path traversal components (‘.’ and ‘..’) are allowed, makes this a safe operation.